#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tracking = (/--tracking[=\s]+([^\s]*)/i).exec(process.argv.join(' '));
const utils_1 = require("@hint/utils");
const trackingEnv = process.env.HINT_TRACKING;
let enableTracking;
if (tracking) {
    enableTracking = tracking[1] === 'on';
}
else if (trackingEnv) {
    enableTracking = trackingEnv === 'on';
}
if (typeof enableTracking !== 'undefined') {
    if (enableTracking) {
        const alreadyRun = utils_1.configStore.get('run');
        const configured = utils_1.appInsights.isConfigured();
        utils_1.appInsights.enable();
        if (!configured) {
            if (!alreadyRun) {
                utils_1.appInsights.trackEvent('FirstRun');
            }
            else {
                utils_1.appInsights.trackEvent('SecondRun');
            }
        }
    }
    else {
        utils_1.appInsights.disable();
    }
}
const cli = require("../lib/cli");
const { trackException, sendPendingData } = utils_1.appInsights;
process.once('uncaughtException', async (err) => {
    console.error(err.message);
    console.error(err.stack);
    trackException(err);
    await sendPendingData();
    process.exit(1);
});
process.once('unhandledRejection', async (r) => {
    const reason = r;
    const source = reason && reason instanceof Error ? reason : reason.error;
    trackException(source);
    await sendPendingData();
    console.error(`Unhandled rejection promise:
    uri: ${source.uri}
    message: ${source.message}
    stack:
${source.stack}`);
    process.exit(1);
});
const run = async () => {
    process.exitCode = await cli.execute(process.argv);
    process.exit(process.exitCode);
};
run();
